@@ -53,6 +53,7 @@ def run_configuration(config_filename, config, arguments):
     encountered_error = None
     error_repository = ''
     prune_create_or_check = {'prune', 'create', 'check'}.intersection(arguments)
+    monitoring_log_level = verbosity_to_log_level(global_arguments.monitoring_verbosity)
 
     try:
         if prune_create_or_check:
@@ -62,6 +63,15 @@ def run_configuration(config_filename, config, arguments):
                 config_filename,
                 monitor.MONITOR_HOOK_NAMES,
                 monitor.State.START,
+                monitoring_log_level,
+                global_arguments.dry_run,
+            )
+        if 'prune' in arguments:
+            command.execute_hook(
+                hooks.get('before_prune'),
+                hooks.get('umask'),
+                config_filename,
+                'pre-prune',
                 global_arguments.dry_run,
             )
         if 'create' in arguments:
@@ -80,10 +90,21 @@ def run_configuration(config_filename, config, arguments):
                 location,
                 global_arguments.dry_run,
             )
+        if 'check' in arguments:
+            command.execute_hook(
+                hooks.get('before_check'),
+                hooks.get('umask'),
+                config_filename,
+                'pre-check',
+                global_arguments.dry_run,
+            )
     except (OSError, CalledProcessError) as error:
+        if command.considered_soft_failure(config_filename, error):
+            return
+
         encountered_error = error
         yield from make_error_log_records(
-            '{}: Error running pre-backup hook'.format(config_filename), error
+            '{}: Error running pre hook'.format(config_filename), error
         )
 
     if not encountered_error:
@@ -109,6 +130,14 @@ def run_configuration(config_filename, config, arguments):
 
     if not encountered_error:
         try:
+            if 'prune' in arguments:
+                command.execute_hook(
+                    hooks.get('after_prune'),
+                    hooks.get('umask'),
+                    config_filename,
+                    'post-prune',
+                    global_arguments.dry_run,
+                )
             if 'create' in arguments:
                 dispatch.call_hooks(
                     'remove_database_dumps',
@@ -125,6 +154,14 @@ def run_configuration(config_filename, config, arguments):
                     'post-backup',
                     global_arguments.dry_run,
                 )
+            if 'check' in arguments:
+                command.execute_hook(
+                    hooks.get('after_check'),
+                    hooks.get('umask'),
+                    config_filename,
+                    'post-check',
+                    global_arguments.dry_run,
+                )
             if {'prune', 'create', 'check'}.intersection(arguments):
                 dispatch.call_hooks(
                     'ping_monitor',
@@ -132,12 +169,16 @@ def run_configuration(config_filename, config, arguments):
                     config_filename,
                     monitor.MONITOR_HOOK_NAMES,
                     monitor.State.FINISH,
+                    monitoring_log_level,
                     global_arguments.dry_run,
                 )
         except (OSError, CalledProcessError) as error:
+            if command.considered_soft_failure(config_filename, error):
+                return
+
             encountered_error = error
             yield from make_error_log_records(
-                '{}: Error running post-backup hook'.format(config_filename), error
+                '{}: Error running post hook'.format(config_filename), error
             )
 
     if encountered_error and prune_create_or_check:
@@ -158,9 +199,13 @@ def run_configuration(config_filename, config, arguments):
                 config_filename,
                 monitor.MONITOR_HOOK_NAMES,
                 monitor.State.FAIL,
+                monitoring_log_level,
                 global_arguments.dry_run,
             )
         except (OSError, CalledProcessError) as error:
+            if command.considered_soft_failure(config_filename, error):
+                return
+
             yield from make_error_log_records(
                 '{}: Error running on-error hook'.format(config_filename), error
             )
@@ -212,6 +257,7 @@ def run_actions(
             local_path=local_path,
             remote_path=remote_path,
             stats=arguments['prune'].stats,
+            files=arguments['prune'].files,
         )
     if 'create' in arguments:
         logger.info('{}: Creating archive{}'.format(repository, dry_run_label))
@@ -225,6 +271,7 @@ def run_actions(
             progress=arguments['create'].progress,
             stats=arguments['create'].stats,
             json=arguments['create'].json,
+            files=arguments['create'].files,
         )
         if json_output:
             yield json.loads(json_output)
@@ -236,6 +283,7 @@ def run_actions(
             consistency,
             local_path=local_path,
             remote_path=remote_path,
+            progress=arguments['check'].progress,
             repair=arguments['check'].repair,
             only_checks=arguments['check'].only,
         )
@@ -347,7 +395,8 @@ def run_actions(
         if arguments['list'].repository is None or validate.repositories_match(
             repository, arguments['list'].repository
         ):
-            logger.info('{}: Listing archives'.format(repository))
+            if not arguments['list'].json:
+                logger.warning('{}: Listing archives'.format(repository))
             json_output = borg_list.list_archives(
                 repository,
                 storage,
@@ -361,7 +410,8 @@ def run_actions(
         if arguments['info'].repository is None or validate.repositories_match(
             repository, arguments['info'].repository
         ):
-            logger.info('{}: Displaying summary info for archives'.format(repository))
+            if not arguments['info'].json:
+                logger.warning('{}: Displaying summary info for archives'.format(repository))
             json_output = borg_info.display_archives_info(
                 repository,
                 storage,
@@ -599,6 +649,7 @@ def main():  # pragma: no cover
             verbosity_to_log_level(global_arguments.verbosity),
             verbosity_to_log_level(global_arguments.syslog_verbosity),
             verbosity_to_log_level(global_arguments.log_file_verbosity),
+            verbosity_to_log_level(global_arguments.monitoring_verbosity),
             global_arguments.log_file,
         )
     except (FileNotFoundError, PermissionError) as error:
